@@ -271,7 +271,7 @@ setMethodS3("fitOneChromosome", "SmoothMultiarrayModel", function(this, chromoso
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # BEGIN: AFFX methods
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
-  cesList <- getListOfChipEffectSets(this);
+  cesList <- getSets(this);
   verbose && cat(verbose, "List of input data sets:");
   verbose && print(verbose, cesList);
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
@@ -431,6 +431,8 @@ setMethodS3("fitOneChromosome", "SmoothMultiarrayModel", function(this, chromoso
 
 ############################################################################
 # HISTORY:
+# 2011-02-19
+# o Replaced deprecated getListOfChipEffectSets() with getSets().
 # 2009-01-26
 # o Updated getPositionChipTypeUnit() of SmoothMultiarrayModel to utilize
 #   the UnitNamesFile Interface instead of assuming an AffymetrixCdfFile.
