@@ -1,4 +1,4 @@
-setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAlleles=TRUE, arrays=NULL, ..., ram=NULL, verbose=FALSE) {
+setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAlleles=TRUE, lengthRange=NULL, arrays=NULL, ..., drop=TRUE, ram=NULL, verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
@@ -20,6 +20,9 @@ setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAll
     arrays <- Arguments$getIndices(arrays, max=nbrOfArrays(csR));
   }
 
+  # Argument 'drop':
+  drop <- Arguments$getLogical(drop);
+
   # Argument 'verbose':
   verbose <- Arguments$getVerbose(verbose);
 
@@ -33,6 +36,13 @@ setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAll
   verbose && cat(verbose, "ram: ", ram);
 
 
+  # List of objects to be returned
+  res <- list();
+  if (!drop) {
+    res <- c(res, list(csR=csR));
+  }
+
+
   verbose && cat(verbose, "Data set");
   verbose && print(verbose, csR);
 
@@ -51,6 +61,10 @@ setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAll
   verbose && print(verbose, csC);
   verbose && exit(verbose);
 
+  if (!drop) {
+    res <- c(res, list(acc=acc, csC=csC));
+  }
+
   # Clean up
   rm(csR, acc);
   gc <- gc();
@@ -74,17 +88,25 @@ setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAll
   verbose && print(verbose, ces);
   verbose && exit(verbose);
 
+  if (!drop) {
+    res <- c(res, list(ces=ces, plm=plm));
+  }
+
   # Clean up
   rm(plm, csC);
   gc <- gc();
   
   verbose && enter(verbose, "CRMAv1/PCR fragment-length normalization");
-  fln <- FragmentLengthNormalization(ces, target="zero");
+  fln <- FragmentLengthNormalization(ces, target="zero", lengthRange=lengthRange);
   verbose && print(verbose, fln);
   cesN <- process(fln, verbose=verbose);
   verbose && print(verbose, cesN);
   verbose && exit(verbose);
 
+  if (!drop) {
+    res <- c(res, list(fln=fln, cesN=cesN));
+  }
+
   # Clean up
   rm(fln, ces);
   gc <- gc();
@@ -94,13 +116,22 @@ setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAll
   verbose && print(verbose, dsNList);
   verbose && exit(verbose);
 
+  if (!drop) {
+    res <- c(res, list(dsNList=dsNList));
+  }
+
   # Clean up
   rm(cesN);
   gc <- gc();
 
   verbose && exit(verbose);
 
-  dsNList;
+  # Return only the final results?
+  if (drop) {
+    res <- dsNList;
+  }
+
+  res;
 }) # doCRMAv1()
 
 
@@ -142,6 +173,11 @@ setMethodS3("doASCRMAv1", "default", function(...) {
 
 ############################################################################
 # HISTORY:
+# 2011-04-07
+# o Added argument 'drop'.
+# 2011-03-14
+# o doCRMAv1() gained argument 'lengthRange', which is passed to 
+#   the constructor of FragmentLengthNormalization.
 # 2010-06-21
 # o Added doASCRMAv1() for a convenient allele-specific CRMAv1 wrapper.
 # 2010-06-07
