@@ -17,19 +17,19 @@ sampleNames <- c("NA06985", "NA06991", "NA06993",
 cdf <- AffymetrixCdfFile$byChipType(chipType, tags="Full,r2");
 print(cdf);
 
-cs <- AffymetrixCelSet$byName(dataSetName, cdf=cdf, verbose=log);
-print(cs);
-stopifnot(identical(getNames(cs), sampleNames));
+csR <- AffymetrixCelSet$byName(dataSetName, cdf=cdf, verbose=log);
+print(csR);
+stopifnot(identical(getNames(csR), sampleNames));
 
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Quantile normalization
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-qn <- QuantileNormalization(cs);
+qn <- QuantileNormalization(csR);
 print(qn);
 csN <- process(qn, verbose=log);
 print(csN);
-stopifnot(identical(getNames(csN), getNames(cs)));
+stopifnot(identical(getNames(csN), getNames(csR)));
 
 
